PAWpySeed: pawpyseed.analysis.run_pawpy.DefectWorkflowWavefunctionHandle Class Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Public Attributes | List of all members
pawpyseed.analysis.run_pawpy.DefectWorkflowWavefunctionHandle Class Reference
Inheritance diagram for pawpyseed.analysis.run_pawpy.DefectWorkflowWavefunctionHandle:
[legend]
Collaboration diagram for pawpyseed.analysis.run_pawpy.DefectWorkflowWavefunctionHandle:
[legend]

## Public Member Functions
def | __init__ (self, bulk_fw_sets, dwo=None)
def | run_pawpy (self)

## Public Attributes
| bulk_fw_sets
| dwo

## Detailed Description

    This class is made to run Kyle's
    wavefunction parsing code...

    bulk_fw_sets is a dict that has bulk fireworks with supercell size as key
    wf_job_run is a string which says if it is "normal" (=gga) or "scan" or "hse"

## Constructor & Destructor Documentation

def pawpyseed.analysis.run_pawpy.DefectWorkflowWavefunctionHandle.__init__ | ( |  | self,
|  |  | bulk_fw_sets,
|  |  | dwo = `None`
| ) |  |

## Member Function Documentation

def pawpyseed.analysis.run_pawpy.DefectWorkflowWavefunctionHandle.run_pawpy | ( |  | self | ) |

    Container for running pawpyseed on all defects in this workflow

## Member Data Documentation

pawpyseed.analysis.run_pawpy.DefectWorkflowWavefunctionHandle.bulk_fw_sets

pawpyseed.analysis.run_pawpy.DefectWorkflowWavefunctionHandle.dwo

The documentation for this class was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/analysis/run_pawpy.py